==> listvennica-0.0.11-sources.jar: listvennica/ModItems.java <==

package listvennica;

import java.util.function.Function;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.fabricmc.fabric.api.item.v1.FabricItemSettings;

public class ModItems {
	public static final class_1792 FLAMEBERRY = register_item ("flameberry", class_1792::new, new FabricItemSettings ());
	public static final class_5321 <class_1761> LISTVENNICA_ITEM_GROUP_KEY = class_5321.method_29179 (
		class_7923.field_44687.method_30517 (),
		new class_2960 (Listvennica.MOD_ID, "listvennica_item_group")
		);
	public static final class_1761 LISTVENNICA_ITEM_GROUP = FabricItemGroup.builder ()
		.method_47320 (() -> new class_1799 (ModItems.FLAMEBERRY))
		.method_47321 (class_2561.method_43471 ("itemGroup.listvennica_item_group"))
		.method_47324 ();
	public static class_1792 register_item (String name, Function <FabricItemSettings, class_1792> itemFactory, FabricItemSettings settings) {
		class_5321 <class_1792> itemKey = class_5321.method_29179 (class_7924.field_41197, new class_2960 (Listvennica.MOD_ID, name));
		class_1792 item = itemFactory.apply (settings);
		class_2378.method_39197 (class_7923.field_41178, itemKey, item);
		Listvennica.LOGGER.info ("Item '" + name + "' is registered");
		return item;
	}
	public static void initialize () {
		class_2378.method_39197 (class_7923.field_44687, LISTVENNICA_ITEM_GROUP_KEY, LISTVENNICA_ITEM_GROUP);
		ItemGroupEvents.modifyEntriesEvent (LISTVENNICA_ITEM_GROUP_KEY).register (itemGroup -> {
			itemGroup.method_45421 (ModItems.FLAMEBERRY);
			itemGroup.method_45421 (ModBlocks.TEST_BLOCK);
			itemGroup.method_45421 (ModBlocks.ACACIA_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_BLOCK_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_STEM_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_STEM_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_ACACIA_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_BIRCH_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_BAMBOO_BLOCK_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_CHERRY_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_CRIMSON_STEM_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_DARK_OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_JUNGLE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_MANGROVE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_SPRUCE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_WARPED_STEM_SLAB.method_8389 ());
		});
	}
}

==> listvennica-0.0.13-sources.jar: listvennica/ModItems.java <==

package listvennica;

import java.util.function.Function;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.fabricmc.fabric.api.loot.v2.LootTableEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1829;
import net.minecraft.class_1834;
import net.minecraft.class_219;
import net.minecraft.class_2246;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_4174;
import net.minecraft.class_5321;
import net.minecraft.class_55;
import net.minecraft.class_77;
import net.minecraft.class_7923;
import net.minecraft.class_7924;

public class ModItems {
	private static final class_2960 BIRCH_LOG_LOOT_TABLE_ID = class_2246.field_10511.method_26162 ();
	private static final class_2960 SPRUCE_LEAVES_LOOT_TABLE_ID = class_2246.field_9988.method_26162 ();
	public static final class_1792 FLAMEBERRY = register_item ("flameberry", class_1792::new, new FabricItemSettings ());
	public static final class_1792 FRETSAW = register_item ("fretsaw", class_1792::new, new FabricItemSettings ());
	public static final class_1792 MACUAHUITL = register_macuahuitl ();
	public static final class_1792 BIRCHBARK = register_item ("birchbark", class_1792::new, new FabricItemSettings ());
	public static final class_1792 CONE = register_item ("cone", class_1792::new, new FabricItemSettings ());
	public static final class_1792 PINE_NUTS = register_pine_nuts ();
	public static final class_5321 <class_1761> LISTVENNICA_ITEM_GROUP_KEY = class_5321.method_29179 (
		class_7923.field_44687.method_30517 (),
		new class_2960 (Listvennica.MOD_ID, "listvennica_item_group")
		);
	public static final class_1761 LISTVENNICA_ITEM_GROUP = FabricItemGroup.builder ()
		.method_47320 (() -> new class_1799 (ModItems.FLAMEBERRY))
		.method_47321 (class_2561.method_43471 ("itemGroup.listvennica_item_group"))
		.method_47324 ();
	public static class_1792 register_item (String name, Function <FabricItemSettings, class_1792> itemFactory, FabricItemSettings settings) {
		class_5321 <class_1792> itemKey = class_5321.method_29179 (class_7924.field_41197, new class_2960 (Listvennica.MOD_ID, name));
		class_1792 item = itemFactory.apply (settings);
		class_2378.method_39197 (class_7923.field_41178, itemKey, item);
		Listvennica.LOGGER.info ("Item '" + name + "' is registered");
		return item;
	}
	public static class_1792 register_macuahuitl () {
		class_5321 <class_1792> itemKey = class_5321.method_29179 (class_7924.field_41197, new class_2960 (Listvennica.MOD_ID, "macuahuitl"));
		class_1792 item = new class_1829 (class_1834.field_8922, 7, -2.4f, new FabricItemSettings ());
		class_2378.method_39197 (class_7923.field_41178, itemKey, item);
		Listvennica.LOGGER.info ("Item 'macuahuitl' is registered");
		return item;
	}
	public static class_1792 register_pine_nuts () {
		class_5321 <class_1792> itemKey = class_5321.method_29179 (class_7924.field_41197, new class_2960 (Listvennica.MOD_ID, "pine_nuts"));
		class_1792 item = new class_1792 (new FabricItemSettings ().method_19265 (new class_4174.class_4175 ().method_19238 (4).method_19237 (0.6f).method_19242 ()));
		class_2378.method_39197 (class_7923.field_41178, itemKey, item);
		Listvennica.LOGGER.info ("Item 'pine_nuts' is registered");
		return item;
	}
	public static void initialize () {
		class_2378.method_39197 (class_7923.field_44687, LISTVENNICA_ITEM_GROUP_KEY, LISTVENNICA_ITEM_GROUP);
		ItemGroupEvents.modifyEntriesEvent (LISTVENNICA_ITEM_GROUP_KEY).register (itemGroup -> {
			itemGroup.method_45421 (ModItems.FLAMEBERRY);
			itemGroup.method_45421 (ModItems.FRETSAW);
			itemGroup.method_45421 (ModItems.MACUAHUITL);
			itemGroup.method_45421 (ModItems.BIRCHBARK);
			itemGroup.method_45421 (ModItems.CONE);
			itemGroup.method_45421 (ModItems.PINE_NUTS);
			itemGroup.method_45421 (ModBlocks.TEST_BLOCK);
			itemGroup.method_45421 (ModBlocks.ACACIA_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_PLANK_WINDOW.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_SIBSTYLE_WINDOW_SHUTTER.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_ICICLES.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_SNAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_SNOWFLAKE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_WOODEN_MOTIF_SPRUCE_CONE.method_8389 ());
			itemGroup.method_45421 (ModBlocks.ACACIA_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BIRCH_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.BAMBOO_BLOCK_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CHERRY_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.CRIMSON_STEM_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.DARK_OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.JUNGLE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.MANGROVE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.SPRUCE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.WARPED_STEM_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_ACACIA_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_BIRCH_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_BAMBOO_BLOCK_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_CHERRY_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_CRIMSON_STEM_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_DARK_OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_JUNGLE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_MANGROVE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_OAK_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_SPRUCE_LOG_SLAB.method_8389 ());
			itemGroup.method_45421 (ModBlocks.STRIPPED_WARPED_STEM_SLAB.method_8389 ());
		});
		LootTableEvents.MODIFY.register ((resourceManager, lootManager, id, tableBuilder, source) -> {
			if (source.isBuiltin () && BIRCH_LOG_LOOT_TABLE_ID.equals (id)) {
				class_55.class_56 poolBuilder = class_55.method_347 ()
					.method_356 (class_219.method_932 (0.125f))
					.method_351 (class_77.method_411 (ModItems.BIRCHBARK));
				tableBuilder.method_336 (poolBuilder);
			}
			if (source.isBuiltin () && SPRUCE_LEAVES_LOOT_TABLE_ID.equals (id)) {
				class_55.class_56 poolBuilder = class_55.method_347 ()
					.method_356 (class_219.method_932 (0.125f))
					.method_351 (class_77.method_411 (ModItems.CONE));
				tableBuilder.method_336 (poolBuilder);
			}
		});
	}
}
